const cheerio = require('cheerio');
const HeadlessChrome = require('simple-headless-chrome-asksuite');
const Util = require('./util');

let options = {
    flags: [
        '-blink-settings=imagesEnabled=false'
    ]
};

const browser = new HeadlessChrome({
    headless: true, // If you turn this off, you can actually see the browser navigate with your instructions
    chrome: options
    // see above if using remote interface
});


function datesAreValid(checkin, checkout) {
    return Util.dateDiffInDays(parseDateBestWestern(checkin), parseDateBestWestern(checkout)) >= 1;
}

async function navigateWebsite(url, checkin, checkout, adultos, criancas, bebes) {
    //let t1 = new Date();

    if (datesAreValid(checkin, checkout)) {

        try {
            await browser.init();

            const mainTab = await browser.newTab({privateTab: false});

            // Navigate to a URL

            let urlBuild = `https://www.bestwestern.com.br/booking-path/hotel-rooms/${url}`;

            console.log(urlBuild);

            await mainTab.setCookie('search_checkInDate', checkin, {domain: 'www.bestwestern.com.br', secure: true});
            await mainTab.setCookie('search_checkOutDate', checkout, {domain: 'www.bestwestern.com.br', secure: true});

            await mainTab.setCookie('search_numAdults', adultos + '', {domain: 'www.bestwestern.com.br', secure: true});
            await mainTab.setCookie('search_numChild', criancas + '', {domain: 'www.bestwestern.com.br', secure: true});

            await mainTab.goTo(urlBuild, {timeout: 20000});
            //console.log("Tempo Url: " + ((new Date() - t1) / 1000) + "s");

            await mainTab.waitForSelectorToLoad('body');
            //console.log("Tempo body: " + ((new Date() - t1) / 1000) + "s");

            const htmlTag = await mainTab.evaluate(function (selector) {
                const selectorHtml = document.querySelector(selector);
                return selectorHtml.innerHTML
            }, 'body'); // returns innerHTML of first matching selector for class "main"


            let $ = cheerio.load(htmlTag.result.value);
            let promise = null;

            let rooms = [];


            $("div[class='group-room resultblock-room-1']").each((index, item) => {

                let room = new HotelRoom();

                let tdx = $(item);

                let exists = true;

                if (exists) {

                    room.name = tdx.find('.roomDetailsTitle').text().trim();
                    room.description = tdx.find('.roomDetailsIcons > span').text();
                    room.amountAdults = 0;
                    room.amountKids = 0;
                    let price = $(tdx.find('div[class="rateBox  initRateBox"]')[0]).attr("data-rate-amount");
                    room.price = Util.toReal(price);
                    room.total = Util.toReal(Util.dateDiffInDays(parseDateBestWestern(checkin), parseDateBestWestern(checkout)) * price);


                    tdx.find('.amenitiesListItem').each((index, itemAmenite) => {
                        room.amenites.push($(itemAmenite).text().trim());
                    });


                    tdx.find('div[class="uk-cover-background uk-position-cover"]').each((index, itemPhoto) => {
                        let photo = $(itemPhoto).attr('style').split("url(\"")[1].replace('");', '');
                        room.images.push(photo);
                    });

                    room.mainPhoto = room.images[0];


                    console.log("td", room);

                    rooms.push(room)
                }
            });


            if (rooms && rooms.length > 0) {

                let obj = {
                    data: rooms,
                    url: urlBuild,
                };

                promise = Promise.resolve(obj)
            } else {
                let obj = {
                    message: $('.error.resortRestriction').text()
                };

                promise = await Promise.reject(obj)
            }

           // console.log("Tempo: " + ((new Date() - t1) / 1000) + "s");
            await browser.close();


            return promise;

        } catch (err) {
            browser.close();
            throw err;
        }
    } else {
        let obj = {
            message: "Datas de pesquisa inválidas. Tente novamente."
        };

        return await Promise.reject(obj)
    }
}

function parseDateBestWestern(dateParam) {
    let dateSplit = dateParam.split("-");
    return new Date(dateSplit[0], dateSplit[1], dateSplit[2])
}




// navigateWebsite('best-western-premier-maceio-maceio-77119', '2018-03-13', '2018-03-14', 2, 1).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui");
//     console.log(error.message);
// });

class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite};



